==> haskell-securemem-0.1.10-268-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 securemem
version:              0.1.10
visibility:           public
id:                   securemem-0.1.10-4t0HOlz4MW924hJuNe1SSf
key:                  securemem-0.1.10-4t0HOlz4MW924hJuNe1SSf
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-securemem
synopsis:
    abstraction to an auto scrubbing and const time eq, memory chunk.

description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.

category:             Data
abi:                  5db81c1262786a9bf4d30d2771956413
exposed:              True
exposed-modules:      Data.SecureMem
import-dirs:          /usr/lib/ghc-9.0.2/site-local/securemem-0.1.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/securemem-0.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-securemem
hs-libraries:         HSsecuremem-0.1.10-4t0HOlz4MW924hJuNe1SSf
depends:
    base-4.15.1.0 byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
    bytestring-0.10.12.1 ghc-prim-0.7.0
    memory-0.17.0-Ba80JGdi30PBt5EgUiQ1Tu

haddock-interfaces:   /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html:         /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-securemem-0.1.10-288-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 securemem
version:              0.1.10
visibility:           public
id:                   securemem-0.1.10-EDfBRjlOKD136c0ZXJQIUL
key:                  securemem-0.1.10-EDfBRjlOKD136c0ZXJQIUL
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-securemem
synopsis:
    abstraction to an auto scrubbing and const time eq, memory chunk.

description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.

category:             Data
abi:                  5378ec7230d1b89740e4a5ec97404e34
exposed:              True
exposed-modules:      Data.SecureMem
import-dirs:          /usr/lib/ghc-9.2.8/site-local/securemem-0.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/securemem-0.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-securemem
hs-libraries:         HSsecuremem-0.1.10-EDfBRjlOKD136c0ZXJQIUL
depends:
    base-4.16.4.0 byteable-0.1.1-2aVcTelA6XA9YKIvhjRaxC
    bytestring-0.11.4.0 ghc-prim-0.8.0
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1

haddock-interfaces:   /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html:         /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
